from PyQt4.QtCore import *
from PyQt4.QtGui import *
import os
import sys
import copy

HOME = os.path.expanduser("~")
LISTPATH = HOME + "/.qlister/"
LISTFILE = LISTPATH + "listfile.txt"
 
class MyMainWindow(QWidget):
    def __init__(self):
        QWidget.__init__(self, None)
        self.initListfile()
        self.setWindowTitle("Qlister")
        self.box = QGridLayout()
        self.lister = QListWidget(self)
        self.lister.setWordWrap(True)
        self.lister.setViewportMargins(0, 0, 0, 0)
        self.lister.setMaximumWidth(480)
        self.lister.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.lister.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
        self.setAttribute(Qt.WA_Maemo5StackedWindow)
        self.autorotating = True
        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
#        self.lister.setStyleSheet("QListView { background-image: url(notepadbg2.png); } QListView::Item { padding-left: 20; padding-right: 20; color: grey; background-color: transparent; background-image: url(itembg.png); }  QListView::indicator:checked { image: url(check.png); } QListView::indicator:unchecked { image: url(uncheck.png); }")
        self.lister.setStyleSheet("QListView { background-color: #f5f5ed; border: 2px solid grey; border-radius: 5px; padding: 3px; margin: 0px; } QListView::item { background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #f5f5ed, stop: 1 #dbd6b6); padding-left: 5px; padding-right: 5px; color: grey; margin: 0}  QListView::indicator:checked { image: url(check.png); } QListView::indicator:unchecked { image: url(uncheck.png); }")
#        self.lister.setStyleSheet("QListView { background-color: #dbd6b6; } QListView::Item { padding-left: 20; padding-right: 20; color: grey; background-color: transparent; background-image: url(itembg.png); }  QListView::indicator:checked { image: url(check.png); } QListView::indicator:unchecked { image: url(uncheck.png); }")
        self.populateList()
        self.rotate = QPushButton("Rotate")
        self.edit = QPushButton("Edit")
        self.box.addWidget(self.lister, 0, 0, 1, 2)
        self.box.addWidget(self.edit, 1, 0, 1, 1)
        self.box.addWidget(self.rotate, 1, 1, 1, 1)
        self.connect(self.rotate, SIGNAL("clicked()"), self.portraitPushed)
        self.connect(self.lister, SIGNAL("itemClicked(QListWidgetItem *)"), self.itemClicked)
        self.connect(self.edit, SIGNAL("clicked()"), self.editPushed)
        self.setLayout(self.box)
 
    def editPushed(self):
        if not self.autorotating:
            self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
        self.connect(self.rotate, SIGNAL("clicked()"), self.portraitPushed)
        a = EditWindow(self)
        a.show()
        
    def portraitPushed(self):
        self.autorotating = False
        self.setAttribute(Qt.WA_Maemo5PortraitOrientation, True)
        self.connect(self.rotate, SIGNAL("clicked()"), self.landscapePushed)


    def landscapePushed(self):
        self.setAttribute(Qt.WA_Maemo5LandscapeOrientation, True)
        self.connect(self.rotate, SIGNAL("clicked()"), self.portraitPushed)
        
    def itemClicked(self, item):
        if item.checkState() == Qt.Checked:
            item.setCheckState(Qt.Unchecked)
            item.setFlags(Qt.ItemIsEnabled | Qt.ItemIsUserCheckable)
        else:
            if len(item.text()) > 0:
                item.setCheckState(Qt.Checked)
                item.setFlags(Qt.ItemIsUserCheckable)

    def initListfile(self):
        if not os.path.exists(LISTPATH):
            print "path not found: " + LISTPATH
            try:
                os.makedirs(LISTPATH)
            except:
                print "failed on mkdir"
                exit()
        if not os.path.isfile(LISTFILE):
            print "file not found: " + LISTFILE
            f = open(LISTFILE, "w")
            f.write(" ")
            f.close()

    def populateList(self):
        f = open(LISTFILE, 'r')
        lines = f.readlines()
        f.close()
        oldlister = []
        if self.lister.count() > 0:
            for i in range(self.lister.count()):
                item = QListWidgetItem()
                item.setText(self.lister.item(i).text())
                item.setCheckState(self.lister.item(i).checkState())
                oldlister.append(item)
        self.lister.clear()
        for line in lines:
            listit = line.strip()
            
            item = QListWidgetItem()
            item.setBackground(QBrush(Qt.NoBrush))
            if len(listit) > 0:
                item.setFlags(Qt.ItemIsEnabled | Qt.ItemIsUserCheckable)
            else:
                item.setFlags(Qt.NoItemFlags)
            item.setCheckState(Qt.Unchecked)
            item.setText(listit)
            self.lister.addItem(item)
        for i in range(len(oldlister)):
            for j in range(self.lister.count()):
                if self.lister.item(j).text() == oldlister[i].text():
                    print "Yeah!"
                    self.lister.item(j).setCheckState(oldlister[i].checkState())
        del oldlister

class EditWindow(QMainWindow):
    def __init__(self, parent):
        QMainWindow.__init__(self, parent)
        self.setWindowTitle("Edit list")
        self.setAttribute(Qt.WA_Maemo5StackedWindow)
        self.setAttribute(Qt.WA_DeleteOnClose)
        w = QFrame(self)
        box = QGridLayout()
        saveButton = QPushButton("Save")
        clearButton = QPushButton("Clear")
        self.connect(saveButton, SIGNAL("clicked()"), self.saveList)
        self.connect(clearButton, SIGNAL("clicked()"), self.clearList)
        self.editarea = QTextEdit(w)
        scroller = self.editarea.property("kineticScroller").toPyObject()
        scroller.setEnabled(True) 
        self.editarea.setPlainText(self.getList())
        box.addWidget(self.editarea, 0, 0, 1, 2)
        box.addWidget(saveButton, 1, 0, 1, 1)
        box.addWidget(clearButton, 1, 1, 1, 1)
        w.setLayout(box)
        self.setCentralWidget(w)
        w.show()

    def clearList(self):
        self.editarea.clear()
        
    def saveList(self):
        self.storeList(self.editarea.toPlainText())
        self.parentWidget().populateList()
        self.close()
        
    def getList(self):
        f = open(LISTFILE, 'r')
        retval = QString(f.read())
        f.close()
        return retval
        
    def storeList(self, filedata):
        f = open(LISTFILE, 'w')
        f.write(filedata.toAscii())
        f.close()

if __name__ == '__main__':
    app = QApplication(sys.argv)
    w = MyMainWindow()
    w.show()
    app.exec_()
    sys.exit()

